@@ -44,7 +44,7 @@ status = HTTPStatus
 ok = partial(status, keepheaders=True)
 
 #: HTTP 201 Created exception factory
-nocontent = partial(ok, 201, 'Created')
+created = partial(ok, 201, 'Created')
 
 #: HTTP 204 No Content exception factory
 nocontent = partial(ok, 204, 'No Content', nobody=True)
